@@ -146,7 +146,12 @@ XS(XS_Data__Util_curried){
             }
         }
 
-        call_sv(proc, GIMME_V | is_method);
+        /* work around RT #69939 */
+        SAVESPTR(ERRSV);
+        call_sv(proc, GIMME_V | is_method | G_EVAL);
+        if(SvTRUE(ERRSV)){
+            croak(NULL); /* rethrow */
+        }
     }
 }
 
@@ -163,6 +168,8 @@ my_call_av(pTHX_ AV* const subs, SV** const args_ary, I32 const args_len){
         XPUSHary(args_ary, 0, args_len);
         PUTBACK;
 
+        /* work around RT #69939 */
+        SAVESPTR(ERRSV);
         call_sv(AvARRAY(subs)[i], G_VOID | G_DISCARD | G_EVAL);
         if(SvTRUE(ERRSV)){
             croak(NULL);
